[][src]Function ipopt_sys::cnlp_create_problem

pub unsafe extern "C" fn cnlp_create_problem(
    p: *mut CNLP_ProblemPtr,
    index_style: CNLP_Index,
    sizes: CNLP_Sizes_CB,
    init: CNLP_Init_CB,
    bounds: CNLP_Bounds_CB,
    eval_f: CNLP_Eval_F_CB,
    eval_g: CNLP_Eval_G_CB,
    eval_grad_f: CNLP_Eval_Grad_F_CB,
    eval_jac_g: CNLP_Eval_Jac_G_CB,
    eval_h: CNLP_Eval_H_CB,
    scaling: CNLP_ScalingParams_CB
) -> CNLP_CreateProblemStatus

Function for creating a new CNLP_Problem object. This function returns an object that can be passed to the cnlp_solve call. It contains the basic definition of the optimization problem via various callbacks.