[][src]Type Definition ipopt_sys::CNLP_Intermediate_CB

type CNLP_Intermediate_CB = Option<unsafe extern "C" fn(alg_mod: CNLP_AlgorithmMode, iter_count: CNLP_Index, obj_value: CNLP_Number, inf_pr: CNLP_Number, inf_du: CNLP_Number, mu: CNLP_Number, d_norm: CNLP_Number, regularization_size: CNLP_Number, alpha_du: CNLP_Number, alpha_pr: CNLP_Number, ls_trials: CNLP_Index, user_data: CNLP_UserDataPtr) -> CNLP_Bool>;

Type defining the callback function for giving intermediate execution control to the user. If set, it is called once per iteration, providing the user with some information on the state of the optimization. This can be used to print some user-defined output. It also gives the user a way to terminate the optimization prematurely. If this method returns false, Ipopt will terminate the optimization.